pitchtools.PitchClassSet
========================

.. abjad-lineage:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet

.. autoclass:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.copy
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.difference
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.from_selection
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.intersection
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.invert
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.is_transposed_subset
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.is_transposed_superset
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.isdisjoint
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.issubset
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.issuperset
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.item_class
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.multiply
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.name
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.new
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.order_by
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.storage_format
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.symmetric_difference
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.transpose
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.union
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__and__
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__contains__
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__eq__
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__ge__
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__gt__
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__hash__
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__iter__
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__le__
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__len__
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__lt__
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__ne__
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__or__
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__repr__
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__str__
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__sub__
      ~abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__xor__

Bases
-----

- :py:class:`pitchtools.Set <abjad.tools.pitchtools.Set.Set.Set>`

- :py:class:`datastructuretools.TypedFrozenset <abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.TypedFrozenset>`

- :py:class:`datastructuretools.TypedCollection <abjad.tools.datastructuretools.TypedCollection.TypedCollection.TypedCollection>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.item_class
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.storage_format
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.copy
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.difference
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.intersection
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.invert
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.is_transposed_subset
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.is_transposed_superset
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.isdisjoint
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.issubset
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.issuperset
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.multiply
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.new
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.order_by
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.symmetric_difference
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.transpose
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.union
   :noindex:

Class methods
-------------

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.from_selection
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__and__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__contains__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__iter__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__len__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__or__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__str__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__sub__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet.__xor__
   :noindex:
